@@ -13,6 +13,7 @@ from ..registration import Registration
 from ..storage import Storage
 from ..storage.log import Log
 from ..storage.record import Record
+from ..submission.component import SubmissionComponent
 from ..utils.dicts import update_dict
 from ..utils.formatting import exception_to_str
 from ..utils.host import get_host_info
@@ -185,6 +186,7 @@ class Component(Mixin):
         self._node: Optional[Component] = node
         self._components: Optional[List[Component]] = None
         self._storage: Optional[Storage] = None
+        self._submission: Optional[SubmissionComponent] = None
         self._events: Events = Events()
         self._actor_config = None
         self.__mixin__ = None
@@ -284,6 +286,15 @@ class Component(Mixin):
         """Log writer instance"""
         return self.storage.log
 
+    @property
+    def submission(self) -> Optional[SubmissionComponent]:
+        """Submission of this component"""
+        if self._storage is None:
+            return None
+        if self._submission is None:
+            self._submission = SubmissionComponent(self.storage.get_url())
+        return self._submission
+
     @property
     def events(self) -> Events:
         """Event interface"""
@@ -298,6 +309,8 @@ class Component(Mixin):
     ):
         # Prepares and dispatches the components lifecycle and returns its result
         try:
+            self.on_start()
+
             self._actor_config = actor_config
 
             if self.node is None and self.on_seeding() is not False:
@@ -307,6 +320,8 @@ class Component(Mixin):
 
             self.storage = Storage.create(storage_config)
 
+            self.on_after_init_storage(storage_config)
+
             self.component_status["started_at"] = str(pendulum.now())
             self.component_status["finished_at"] = False
             self.refresh_status(log_errors=True)
@@ -364,16 +379,25 @@ class Component(Mixin):
 
             status = self.execute()
             self.destroy()
+
+            self.on_success(status)
+            self.on_finish(status, success=True)
         except (KeyboardInterrupt, SystemExit):
             status = ExecutionException(
                 reason="user_interrupt",
                 message="The components execution has been interrupted by the user or system.",
             )
+            self.on_failure(status)
+            self.on_finish(status, success=False)
         except BaseException as ex:
             status = ExecutionException(
                 reason="exception",
                 message=f"The following exception occurred: {ex}\n{exception_to_str(ex)}",
             )
+            self.on_failure(status)
+            self.on_finish(status, success=False)
+        finally:
+            OutputRedirection.revert()
 
         return status
 
@@ -479,8 +503,6 @@ class Component(Mixin):
         self.component_status["finished_at"] = str(pendulum.now())
         self.refresh_status(log_errors=True)
 
-        OutputRedirection.revert()
-
         self.on_after_destroy()
 
     def refresh_status(self, log_errors=False):
@@ -568,6 +590,9 @@ class Component(Mixin):
 
     # life cycle
 
+    def on_start(self):
+        """Lifecycle event triggered at the very beginning of the component dispatch"""
+
     def on_seeding(self):
         """Lifecycle event to implement custom seeding
 
@@ -652,6 +677,9 @@ class Component(Mixin):
         """Lifecycle event triggered at write initialisation"""
         pass
 
+    def on_after_init_storage(self, storage_config: Dict):
+        """Lifecycle event triggered when storage is available"""
+
     def on_after_create(self):
         """Lifecycle event triggered after components creation"""
         pass
@@ -709,6 +737,27 @@ class Component(Mixin):
         """Lifecycle event triggered after components destruction"""
         pass
 
+    def on_finish(self, result, success):
+        """Lifecycle event triggered right before the end of the component execution
+
+        # Arguments
+        success: Whether the execution finished sucessfully
+        """
+
+    def on_success(self, result):
+        """Lifecycle event triggered iff execution finishes successfully
+
+        # Arguments
+        result: Return value of on_execute event
+        """
+
+    def on_failure(self, result):
+        """Lifecycle event triggered iff execution finished with an exception
+
+        # Arguments
+        result: Execution exception
+        """
+
     def __repr__(self):
         if isinstance(self.node, Component):
             return "Sub" + repr(self.node)
