@@ -19,7 +19,7 @@ class RayEngine(Engine):
     def serialize(self):
         return {"type": "ray"}
 
-    def _submit(self, execution):
+    def _dispatch(self, execution):
         if not ray.is_initialized():
             ray.init()
 
@@ -56,7 +56,9 @@ class RayEngine(Engine):
     ):
         if isinstance(component["class"], FunctionalComponent):
             nd = ray.remote(resources=resources)(FunctionalComponent).remote(
-                component["class"].function, component["args"], component["flags"],
+                component["class"].function,
+                component["args"],
+                component["flags"],
             )
         else:
             # load lazy module
