@@ -170,7 +170,8 @@ class SlurmEngine(Engine):
             # submit to slurm
             try:
                 sbatch_arguments = []
-                for k, v in self.canonicalize_resources(resources).items():
+                canonical_resources = self.canonicalize_resources(resources)
+                for k, v in canonical_resources.items():
                     sbatch_arguments.append(k)
                     if v not in [None, True]:
                         sbatch_arguments.append(str(v))
@@ -181,14 +182,12 @@ class SlurmEngine(Engine):
                     job_id = int(output.rsplit(" ", maxsplit=1)[-1])
                 except ValueError:
                     job_id = False
-                info = self.serialize()
-                info.update(
-                    {
-                        "job_id": job_id,
-                        "cmd": "sbatch " + " ".join(sbatch_arguments),
-                        "script": target,
-                    }
-                )
+                info = {
+                    "job_id": job_id,
+                    "cmd": "sbatch " + " ".join(sbatch_arguments),
+                    "script": target,
+                    "resources": canonical_resources,
+                }
                 execution.set_result(info, echo=False)
                 execution.storage.save_file(f"{component_id}/engine/info.json", info)
             except Exception as ex:
