@@ -61,17 +61,30 @@ class Registration:
         """
         pass
 
+    def on_before_component_construction(self):
+        """Event triggered before the component is constructed.
+
+        For example, if the component module requires environment variables etc. before initial construction,
+        this event can be used to set them.
+
+        # Arguments
+
+        """
+
+    # disable unless overridden
+    on_before_component_construction._deactivated = True
+
     def on_before_component_import(self, module, baseclass, default):
         """Event triggered before a component is imported from a module
 
-        You can prevent the import and return a component from this method to be used instead.
+        You can prevent the import and return a component or an alternative module import path
+        from this method to be used instead.
 
         # Arguments
         module: String, the module path that is about to be imported
         baseclass: The component baseclass (either Component or Mixin)
         default: Optional default component that will be used if import fails
         """
-        pass
 
     def on_component_import(self, component_candidate, module, baseclass, default):
         """Event triggered during component import from a module
@@ -87,7 +100,6 @@ class Registration:
         baseclass: The component baseclass (either Component or Mixin)
         default: Optional default component that will be used if import fails
         """
-        pass
 
     def on_resolve_vendor(self, name, config, target):
         """Event triggered when vendor is resolved
@@ -102,7 +114,13 @@ class Registration:
 
         Return False to prevent the default automatic resolution
         """
-        pass
+
+    def host_information(self) -> dict:
+        """Returned dictionary will be recorded as host information
+
+        Note that explicitly registered host methods take precedence over returned data
+        """
+        return {}
 
     def default_resources(self, engine, component, components):
         """Allows to specify global default resources"""
