@@ -186,6 +186,13 @@ class Submission:
         """True if starting time has been written"""
         return bool(self.started_at)
 
+    @property
+    def engine(self):
+        """Returns information on the engine"""
+        if "engine" not in self._cache:
+            self._cache["engine"] = config_map(self.file("engine.json"))
+        return self._cache["engine"]
+
     @property
     def host(self):
         """Returns information on the experiment host"""
