@@ -2,10 +2,9 @@ import importlib
 import inspect
 import os
 
-from machinable.registration import Registration
-from machinable.utils.formatting import exception_to_str
-
+from ..registration import Registration
 from ..utils.formatting import exception_to_str
+from .formatting import exception_to_str
 
 
 def resolve_instance(arg, instance_type, default_path=""):
@@ -76,7 +75,9 @@ class ModuleClass:
             on_before_component_import = registration.on_before_component_import(
                 module=self.module_name, baseclass=self.baseclass, default=default
             )
-            if on_before_component_import is not None:
+            if isinstance(on_before_component_import, str):
+                self.module_name = on_before_component_import
+            elif on_before_component_import is not None:
                 return on_before_component_import
 
         module_class = None
