@@ -1,6 +1,6 @@
 import pytest
 
-from machinable import Experiment
+from machinable import C, Experiment
 from machinable.config.interface import ConfigInterface
 from machinable.experiment.parser import parse_experiment
 from machinable.project import Project
@@ -42,6 +42,84 @@ def to_config(project, schedule):
         return node_config["args"], components_config["args"]
 
 
+def test_config_mixins():
+    test_project = Project("./test_project")
+
+    t = Experiment().component("mixexp", ("~test", dict(_mixins_=["version_mixin"])))
+    e, m = to_config(test_project, t)
+    assert "elephant" not in e
+    assert e["mixed_in"] is True
+    assert e["foo"] == 1
+
+    t = Experiment().component(
+        "mixexp", ("~test", dict(_mixins_=["^", "version_mixin"]))
+    )
+    e, m = to_config(test_project, t)
+    assert "elephant" in e
+    assert e["mixed_in"] is True
+    assert e["foo"] == 1
+
+    t = Experiment().component("thenode", ("~test", dict(_mixins_=["version_mixin"])))
+    e, m = to_config(test_project, t)
+    assert e["mixed_in"] is True
+    assert e["foo"] == 1
+
+    t = Experiment().component(
+        "thenode", ("~test:nest", dict(_mixins_=["^", "version_mixin"]))
+    )
+    e, m = to_config(test_project, t)
+    assert e["mixed_in"] is None
+    assert e["foo"] == 1
+    assert e["ba"] == 2
+
+    t = Experiment().component(
+        "thenode", ("~three:nested", dict(_mixins_=["version_mixin", "^"]))
+    )
+    e, m = to_config(test_project, t)
+    assert e["alpha"] == 4
+    assert e["added"] == "blocker"
+    assert e["unaffected"] == "value"
+    assert e["beta"] == "override"
+
+    # override mixins in version
+    t = Experiment().component(
+        "thenode", ({"_mixins_": ["trait", "version_mixin"]}, "~three:nested")
+    )
+    e, m = to_config(test_project, t)
+    assert e["alpha"] == 4
+    assert e["added"] == "blocker"
+    assert e["unaffected"] == "value"
+    assert e["beta"] == "override"
+
+    t = Experiment().component(
+        "thenode",
+        ({"_mixins_": [{"name": "version_mixin", "overrides": True}]}, "~three:nested"),
+    )
+    e, m = to_config(test_project, t)
+    assert e["alpha"] == 4
+    assert e["added"] == "blocker"
+    assert e["unaffected"] == "value"
+    assert e["beta"] == "override"
+
+    t = Experiment().component(
+        "thenode",
+        (
+            {
+                "_mixins_": [
+                    {"name": "trait", "overrides": False},
+                    {"name": "mixin_module", "overrides": False},
+                    "version_mixin",
+                    "^",
+                ]
+            },
+            "~three:nested",
+        ),
+    )
+    e, m = to_config(test_project, t)
+    assert e["key"]["very"] is None
+    assert e["hello"] == "there"
+
+
 def test_config_versioning():
     test_project = Project("./test_project")
 
@@ -98,10 +176,6 @@ def test_config_versioning():
     assert m["alpha"] == 0
     assert m["key"]["mixing"] == "is"
 
-    t = Experiment().components(("thenode", "./test_project/version_override.json"))
-    e, m = to_config(test_project, t)
-    assert e["alpha"] == 10
-
     # ingores None
     t = Experiment().components(("thenode", (None, {"alpha": -1}, None)))
     e, m = to_config(test_project, t)
