@@ -15,7 +15,7 @@ def test_config_mapping_evaluate():
             "_mixin_": True,
             "~version": {"should be": "hidden"},
         }
-    ).toDict(with_hidden=False)
+    ).as_dict(discard_hidden=True)
 
     assert "_hidden" not in m
     assert m["_mixin_"]
@@ -40,11 +40,18 @@ def test_config_mapping_versions():
 
 
 def test_config_mapping_diff():
-    m = ConfigMap({"test": 1, "~a": {"a": "1"},})
-    assert (
-        "root['test']"
-        in m.get_deep_diff({"test": 2, "~a": {"a": "1"},})["values_changed"]
+    m = ConfigMap(
+        {
+            "test": 1,
+            "~a": {"a": "1"},
+        }
     )
+    assert "root['test']" in m.get_deep_diff(
+        {
+            "test": 2,
+            "~a": {"a": "1"},
+        }
+    )["values_changed"]
 
 
 class TestReadme(unittest.TestCase):
@@ -76,7 +83,7 @@ class TestReadme(unittest.TestCase):
         m = ConfigMap(d)
         self.assertEqual(m.a, 1)
         self.assertEqual(m.b, 2)
-        d2 = m.toDict()
+        d2 = m.as_dict()
         self.assertIsInstance(d2, dict)
         self.assertNotIsInstance(d2, ConfigMap)
         self.assertEqual(len(d2), 3)
@@ -160,7 +167,11 @@ class TestBasic(unittest.TestCase):
     def test_list_comprehension(self):
         parentDict = {
             "name": "Father1",
-            "offspring": [{"name": "Child1"}, {"name": "Child2"}, {"name": "Child3"},],
+            "offspring": [
+                {"name": "Child1"},
+                {"name": "Child2"},
+                {"name": "Child3"},
+            ],
         }
         parent = ConfigMap(parentDict)
         ordered_names = ["Child1", "Child2", "Child3"]
@@ -228,7 +239,7 @@ class TestRecursive(unittest.TestCase):
         outStr = str(m)
         self.assertIn("""a=5""", outStr)
         self.assertIn("""recursive=ConfigMap(...)""", outStr)
-        d = m.toDict()
+        d = m.as_dict()
         d_id = id(d)
         d["a"] = 5
         d["recursive"] = d
@@ -253,7 +264,7 @@ class Testkwarg(unittest.TestCase):
         def capture(**kwargs):
             return kwargs
 
-        self.assertEqual(a, capture(**b.toDict()))
+        self.assertEqual(a, capture(**b.as_dict()))
 
 
 class TestDeepCopy(unittest.TestCase):
@@ -292,7 +303,7 @@ class TestDeepCopy(unittest.TestCase):
 class TestConfigMapTupleToDict(unittest.TestCase):
     def test(self):
         m = ConfigMap({"a": 1, "b": (11, 22, ConfigMap({"c": 3}))})
-        d = m.toDict()
+        d = m.as_dict()
         self.assertEqual(d, {"a": 1, "b": (11, 22, {"c": 3})})
 
 
