@@ -9,18 +9,24 @@ def test_execution_resolve():
     with pytest.raises(ValueError):
         resolve_instance("@", Engine, default_path="test_project")
     assert isinstance(
-        resolve_instance("@", Engine, default_path="test_project/engines"), Engine,
+        resolve_instance("@", Engine, default_path="test_project/_machinable/engines"),
+        Engine,
     )
     assert isinstance(
-        resolve_instance("@named", Engine, default_path="test_project/engines"),
+        resolve_instance(
+            "@named", Engine, default_path="test_project/_machinable/engines"
+        ),
         Detached,
     )
 
 
 def test_execution_resolvers():
     execution = execute(
-        "@/test_project/experiments",
-        engine="@/test_project/engines",
+        "@/test_project/_machinable/experiments",
+        engine="@/test_project/_machinable/engines",
         project="./test_project",
     )
-    assert execution.experiment.specification["name"] == "test_project.experiments"
+    assert (
+        execution.experiment.specification["name"]
+        == "test_project._machinable.experiments"
+    )
