@@ -14,6 +14,8 @@ def test_sql_index(helpers):
     latest = index.find_latest()
     assert len(latest) > 0
     since = latest.first().started_at
-    experiments = index.find_latest(since=since)
-    assert len(experiments) == 0
+    submissions = index.find_latest(since=since)
+    assert len(submissions) == 0
     assert len(index.find_all()) > 0
+    submission = index.find("tttttt")
+    assert len(submission.components) == 4
