@@ -13,3 +13,6 @@ class ConfMethods(Component):
 
     def config_arghello(self, arg):
         return arg
+
+    def config_recursive_call(self, arg):
+        return self.config.method + str(arg)
